@@ -246,6 +246,14 @@ class ServiceUserForIAC(core.Construct):
                         "arn:aws:kendra:eu-west-1:*:*" + app_name + "*",
                     ],
                 ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "cloudwatch:*",
+                    ],
+                    resources=[
+                        "arn:aws:cloudwatch:*:*:dashboard/" + app_name + "*",
+                    ],
+                ),
                 # Filter by TAG
                 _iam.PolicyStatement(
                     actions=[
@@ -295,6 +303,16 @@ class ServiceUserForIAC(core.Construct):
                         }
                     },
                 ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "cloudwatch:*",
+                    ],
+                    conditions={
+                            "ForAnyValue:StringLikeIfExists": {
+                                "ec2:ResourceTag/ApplicationName": app_name
+                            }
+                        },
+                ),
                 # Filter by SPECIFIC RESOURCE
                 _iam.PolicyStatement(
                     actions=[
